@@ -44,13 +44,6 @@ fmtExtra
   return buff;
 }
 
-static const char *
-fmtValu_0
-(const double values[], int alarm, int beep) {
-  sprintf (buff, "%.0f", values[0]);
-  return fmtExtra (alarm, beep);
-}
-
 static const char *
 fmtTemps_0
 (const double values[], int alarm, int beep) {
@@ -252,8 +245,6 @@ static const FeatureDescriptor adm1021_features[] = {
     { SENSORS_ADM1021_TEMP, SENSORS_ADM1021_TEMP_HYST, SENSORS_ADM1021_TEMP_OVER, -1 } }, /* hyst=min, over=max */
   { fmtTemps_ADM1021_1, rrdF0, DataType_temperature, ADM1021_ALARM_RTEMP_HIGH | ADM1021_ALARM_RTEMP_LOW | ADM1021_ALARM_RTEMP_NA, 0,
     { SENSORS_ADM1021_REMOTE_TEMP, SENSORS_ADM1021_REMOTE_TEMP_HYST, SENSORS_ADM1021_REMOTE_TEMP_OVER, -1 } }, /* hyst=min, over=max */
-  { fmtValu_0, NULL, DataType_other, 0, 0,
-    { SENSORS_ADM1021_DIE_CODE, -1 } },
   { NULL }
 };
 
@@ -547,6 +538,46 @@ static const ChipDescriptor lm80_chip = {
   lm80_names, lm80_features, SENSORS_LM80_ALARMS, 0
 };
 
+/** LM85 **/
+
+static const char *lm85_names[] = {
+  SENSORS_LM85_PREFIX, SENSORS_LM85B_PREFIX, SENSORS_LM85C_PREFIX,
+  SENSORS_ADM1027_PREFIX, SENSORS_ADT7463_PREFIX,
+  SENSORS_EMC6D100_PREFIX, SENSORS_EMC6D102_PREFIX, NULL
+};
+
+static const FeatureDescriptor lm85_features[] = {
+  { fmtVolts_2, rrdF2, DataType_voltage, LM85_ALARM_IN0, 0,
+    { SENSORS_LM85_IN0, SENSORS_LM85_IN0_MIN, SENSORS_LM85_IN0_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM85_ALARM_IN1, 0,
+    { SENSORS_LM85_IN1, SENSORS_LM85_IN1_MIN, SENSORS_LM85_IN1_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM85_ALARM_IN2, 0,
+    { SENSORS_LM85_IN2, SENSORS_LM85_IN2_MIN, SENSORS_LM85_IN2_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM85_ALARM_IN3, 0,
+    { SENSORS_LM85_IN3, SENSORS_LM85_IN3_MIN, SENSORS_LM85_IN3_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM85_ALARM_IN4, 0,
+    { SENSORS_LM85_IN4, SENSORS_LM85_IN4_MIN, SENSORS_LM85_IN4_MAX, -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, LM85_ALARM_FAN1, 0,
+    { SENSORS_LM85_FAN1, SENSORS_LM85_FAN1_MIN, -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, LM85_ALARM_FAN2, 0,
+    { SENSORS_LM85_FAN2, SENSORS_LM85_FAN2_MIN, -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, LM85_ALARM_FAN3, 0,
+    { SENSORS_LM85_FAN3, SENSORS_LM85_FAN3_MIN, -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, LM85_ALARM_FAN4, 0,
+    { SENSORS_LM85_FAN4, SENSORS_LM85_FAN4_MIN, -1 } },
+  { fmtTemps_minmax_0, rrdF1, DataType_temperature, LM85_ALARM_TEMP1, 0,
+    { SENSORS_LM85_TEMP1, SENSORS_LM85_TEMP1_MIN, SENSORS_LM85_TEMP1_MAX, -1 } },
+  { fmtTemps_minmax_0, rrdF1, DataType_temperature, LM85_ALARM_TEMP2, 0,
+    { SENSORS_LM85_TEMP2, SENSORS_LM85_TEMP2_MIN, SENSORS_LM85_TEMP2_MAX, -1 } },
+  { fmtTemps_minmax_0, rrdF1, DataType_temperature, LM85_ALARM_TEMP3, 0,
+    { SENSORS_LM85_TEMP3, SENSORS_LM85_TEMP3_MIN, SENSORS_LM85_TEMP3_MAX, -1 } },
+  { NULL }
+};
+
+static const ChipDescriptor lm85_chip = {
+  lm85_names, lm85_features, SENSORS_LM85_ALARMS, 0
+};
+
 /** LM87 **/
 
 static const char *lm87_names[] = {
@@ -1395,6 +1426,29 @@ static const ChipDescriptor w83793_chip = {
   w83793_names, w83793_features, 0, 0
 };
 
+/** LM90 **/
+
+static const char *lm90_names[] = {
+  SENSORS_LM90_PREFIX, SENSORS_ADM1032_PREFIX, SENSORS_LM99_PREFIX, SENSORS_LM86_PREFIX,
+  SENSORS_MAX6657_PREFIX, SENSORS_ADT7461_PREFIX, NULL
+};
+
+static const FeatureDescriptor lm90_features[] = {
+  { fmtTemps_PC87360_1, rrdF1, DataType_temperature,
+    LM90_ALARM_LOCAL_HIGH | LM90_ALARM_LOCAL_LOW | LM90_ALARM_LOCAL_CRIT, 0,
+    { SENSORS_LM90_LOCAL_TEMP, SENSORS_LM90_LOCAL_LOW,
+      SENSORS_LM90_LOCAL_HIGH, SENSORS_LM90_LOCAL_TCRIT, -1 } },
+  { fmtTemps_PC87360_1, rrdF1, DataType_temperature,
+    LM90_ALARM_REMOTE_HIGH | LM90_ALARM_REMOTE_LOW | LM90_ALARM_REMOTE_CRIT, 0,
+    { SENSORS_LM90_REMOTE_TEMP, SENSORS_LM90_REMOTE_LOW,
+      SENSORS_LM90_REMOTE_HIGH, SENSORS_LM90_REMOTE_TCRIT, -1 } },
+  { NULL }
+};
+
+static const ChipDescriptor lm90_chip = {
+  lm90_names, lm90_features, SENSORS_LM90_ALARMS, 0
+};
+
 
 /** ALL **/
 
@@ -1407,6 +1461,7 @@ const ChipDescriptor * const knownChips[] = {
   &lm75_chip,
   &lm78_chip,
   &lm80_chip,
+  &lm85_chip,
   &lm87_chip,
   &max1617_chip,
   &maxilife_chip,
@@ -1426,5 +1481,6 @@ const ChipDescriptor * const knownChips[] = {
   &vt1211_chip,
   &k8temp_chip,
   &w83793_chip,
+  &lm90_chip,
   NULL
 };
